@@ -93,7 +93,11 @@ public Q_SLOTS:
     void slotFormatPainter(bool active);
     void ensureCursorVisibleDelayed();
 
+protected:
+    bool event(QEvent *ev) override;
+
 private:
+    void regenerateColorScheme();
     class RichTextComposerControlerPrivate;
     std::unique_ptr<RichTextComposerControlerPrivate> const d;
 };
