@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -43,10 +43,10 @@ private:
     QSlider *mVolume = nullptr;
     QSlider *mRate = nullptr;
     QSlider *mPitch = nullptr;
-    TextToSpeechLanguageComboBox *mLanguage = nullptr;
+    TextToSpeechLanguageComboBox *const mLanguage;
     AbstractTextToSpeechConfigInterface *mAbstractTextToSpeechConfigInterface = nullptr;
-    QComboBox *mAvailableEngine = nullptr;
-    QComboBox *mVoice = nullptr;
+    QComboBox *const mAvailableEngine;
+    QComboBox *const mVoice;
 };
 }
 
